==> crystal-facet-uml_1.25.1.orig.tar.gz: crystal_facet_uml-1.25.1/gui/source/resources/edit_attributes_sect.c <==
/* GIMP RGBA C-Source image dump (edit_attributes_sect.c) */

static const struct {
  guint  	 width;
  guint  	 height;
  guint  	 bytes_per_pixel; /* 2:RGB16, 3:RGB, 4:RGBA */ 
  guint8 	 pixel_data[48 * 12 * 4 + 1];
} edit_attributes_sect = {
  48, 12, 4,
  "\200\200\200\350\200\200\200\374\200\200\200\374\200\200\200\374\200\200"
  "\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374"
  "\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200"
  "\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374"
  "\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200"
  "\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374"
  "\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200"
  "\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374"
  "\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200"
  "\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374"
  "\200\200\200\374\200\200\200\374\200\200\200\374UUU\003\200\200\200\004\200\200"
  "\200\004\200\200\200\004\200\200\200\004\200\200\200\004\200\200\200\004\200\200\200"
  "\004\200\200\200\004\200\200\200\004\200\200\200\004\200\200\200\004\200\200\200\004"
  "\200\200\200\004\200\200\200\004\200\200\200\004\200\200\200\004\200\200\200\004\200"
  "\200\200\004\200\200\200\004\200\200\200\004\200\200\200\004\200\200\200\004\200\200"
  "\200\004\200\200\200\004\200\200\200\004\200\200\200\004\200\200\200\004\200\200\200"
  "\004\200\200\200\004\200\200\200\004\200\200\200\004\200\200\200\004\200\200\200\004"
  "\200\200\200\004\200\200\200\004\200\200\200\004\200\200\200\004\200\200\200\004\200"
  "\200\200\004\200\200\200\004\200\200\200\004\200\200\200\004\200\200\200\004\200\200"
  "\200\004\200\200\200\004\200\200\200\004\200\200\200\004\000\000\000\000\364\377\000\312\364"
  "\377\000\356\364\377\000\356\364\377\000\341\363\377\000\335\363\377\000\335\363\377"
  "\000\335\363\377\000\335\363\377\000\335\363\377\000\335\363\377\000\335\363\377\000"
  "\335\363\377\000\335\363\377\000\335\363\377\000\335\363\377\000\335\363\377\000\335"
  "\363\377\000\335\363\377\000\335\363\377\000\335\363\377\000\335\363\377\000\335\363"
  "\377\000\335\364\377\000\324\364\377\000\314\364\377\000\310\364\377\000\245\364\377"
  "\000x\363\377\000R\364\377\000\060\355\377\000\016\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\365\377\000\333\364\377\000\377\364\377\000\377"
  "\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364"
  "\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377"
  "\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000"
  "\377\364\377\000\377\364\377\000\375\364\377\000\326\364\377\000\237\365\377\000h\365"
  "\377\000\062\377\377\000\007\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\363\377\000\335\364\377"
  "\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000"
  "\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377"
  "\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364"
  "\377\000\327\365\377\000\223\365\377\000P\357\377\000\020\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\364\377\000\340\364\377\000"
  "\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377"
  "\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364"
  "\377\000\377\364\377\000\371\364\377\000\264\365\377\000b\366\377\000\033\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\364\377\000\343\364\377\000\377\364\377\000\377\364\377"
  "\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000"
  "\377\364\377\000\377\364\377\000\370\364\377\000\273\364\377\000o\363\377\000\025\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\364\377\000\345\364"
  "\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377"
  "\000\377\364\377\000\377\364\377\000\330\364\377\000o\357\377\000\020\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\364\377"
  "\000\351\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000"
  "\375\364\377\000\273\365\377\000M\377\377\000\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\364\377"
  "\000\352\364\377\000\377\364\377\000\377\364\377\000\367\365\377\000\222\367\377\000"
  "\036\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\364\377\000\355\364\377"
  "\000\373\363\377\000\227\366\377\000\033\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\363\377\000\256\364\377\000-\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000",
};

==> crystal-facet-uml_1.26.1.orig.tar.gz: crystal_facet_uml-1.26.1/gui/source/resources/edit_attributes_sect.c <==
/* GIMP RGBA C-Source image dump (edit_attributes_sect.c) */

static const struct {
  guint  	 width;
  guint  	 height;
  guint  	 bytes_per_pixel; /* 2:RGB16, 3:RGB, 4:RGBA */ 
  guint8 	 pixel_data[48 * 12 * 4 + 1];
} edit_attributes_sect = {
  48, 12, 4,
  "\200\200\200\350\200\200\200\374\200\200\200\374\200\200\200\374\200\200"
  "\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374"
  "\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200"
  "\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374"
  "\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200"
  "\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374"
  "\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200"
  "\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374"
  "\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200"
  "\200\374\200\200\200\374\200\200\200\374\200\200\200\374\200\200\200\374"
  "\200\200\200\374\200\200\200\374\200\200\200\374\325\343\016\022\327\344\033"
  "\023\327\344\033\023\327\344\033\023\327\344\033\023\327\344\033\023\327\344\033\023"
  "\327\344\033\023\327\344\033\023\327\344\033\023\327\344\033\023\327\344\033\023\327"
  "\344\033\023\327\344\033\023\327\344\033\023\327\344\033\023\327\344\033\023\327\344"
  "\033\023\327\344\033\023\327\344\033\023\327\344\033\023\327\344\033\023\327\344\033"
  "\023\327\344\033\023\327\344\033\023\327\344\033\023\327\344\033\023\327\344\033\023"
  "\327\344\033\023\327\344\033\023\327\344\033\023\327\344\033\023\327\344\033\023\327"
  "\344\033\023\327\344\033\023\327\344\033\023\327\344\033\023\327\344\033\023\327\344"
  "\033\023\327\344\033\023\327\344\033\023\327\344\033\023\327\344\033\023\327\344\033"
  "\023\327\344\033\023\327\344\033\023\327\344\033\023\325\343\034\022\364\377\000\377"
  "\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364"
  "\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377"
  "\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000"
  "\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377"
  "\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364"
  "\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377"
  "\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000"
  "\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377"
  "\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\374\364"
  "\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377"
  "\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000"
  "\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377"
  "\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364"
  "\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377"
  "\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000"
  "\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377"
  "\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364"
  "\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377"
  "\000\374\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000"
  "\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377"
  "\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364"
  "\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377"
  "\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000"
  "\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377"
  "\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364"
  "\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377"
  "\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000"
  "\377\364\377\000\374\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377"
  "\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364"
  "\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377"
  "\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000"
  "\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377"
  "\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364"
  "\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377"
  "\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000"
  "\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377"
  "\364\377\000\377\364\377\000\374\364\377\000\377\364\377\000\377\364\377\000\377\364"
  "\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377"
  "\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000"
  "\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377"
  "\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364"
  "\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377"
  "\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000"
  "\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377"
  "\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364\377\000\377\364"
  "\377\000\377\364\377\000\377\364\377\000\374\364\377\000\355\364\377\000\355\364\377"
  "\000\355\364\377\000\355\364\377\000\355\364\377\000\355\364\377\000\355\364\377\000"
  "\355\364\377\000\355\364\377\000\355\364\377\000\355\364\377\000\355\364\377\000\355"
  "\364\377\000\355\364\377\000\355\364\377\000\355\364\377\000\355\364\377\000\355\364"
  "\377\000\355\364\377\000\355\364\377\000\355\364\377\000\355\364\377\000\355\364\377"
  "\000\355\364\377\000\355\364\377\000\355\364\377\000\355\364\377\000\355\364\377\000"
  "\355\364\377\000\355\364\377\000\355\364\377\000\355\364\377\000\355\364\377\000\355"
  "\364\377\000\355\364\377\000\355\364\377\000\355\364\377\000\355\364\377\000\355\364"
  "\377\000\355\364\377\000\355\364\377\000\355\364\377\000\355\364\377\000\355\364\377"
  "\000\355\364\377\000\355\364\377\000\355\364\377\000\351\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000"
  "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000",
};
